@@ -30,7 +30,8 @@ class Puppet::Relationship
   end
 
   def event=(event)
-    raise ArgumentError, "You must pass a callback for non-NONE events" if event != :NONE and ! callback
+    #TRANSLATORS 'NONE' should not be translated
+    raise ArgumentError, _("You must pass a callback for non-NONE events") if event != :NONE and ! callback
     @event = event
   end
 
